@@ -10,7 +10,7 @@ from abc import abstractmethod
 from ruamel.yaml import safe_load
 from capanno_utils.repo_config import *
 from ...classes.metadata.shared_properties import CodeRepository, WebSite, Person, Publication, Keyword, CallMap
-from ...classes.metadata.common_functions import _mk_hashes, CommonPropsMixin, SoftwarePropsMixin
+from ...classes.metadata.common_functions import _mk_hashes, CommonPropsMixin, SoftwarePropsMixin, get_description_from_file
 from ...classes.metadata.metadata_base import MetadataBase
 
 class WorkflowMetadataBase(MetadataBase):
@@ -65,6 +65,7 @@ class WorkflowMetadata(CommonPropsMixin, SoftwarePropsMixin, WorkflowMetadataBas
         ('softwareVersion', None),
         ('current', False),
         ('description', None),
+        ('shortDescription', None),
         ('identifier', None),
         ('metadataStatus', 'Incomplete'),
         ('workflowStatus', 'Incomplete'),
@@ -142,9 +143,11 @@ class WorkflowMetadata(CommonPropsMixin, SoftwarePropsMixin, WorkflowMetadataBas
     def load_from_file(cls, file_path, ignore_empties=False):
         file_path = Path(file_path)
         with file_path.open('r') as file:
-            file_dict = safe_load(file)
+            wf_kwargs_dict = safe_load(file)
+        if not wf_kwargs_dict.get('description'):  # No description specified. Check for it in file.
+            wf_kwargs_dict['description'] = get_description_from_file(file_path)
         try:
-            return cls(**file_dict, ignore_empties=ignore_empties)
+            return cls(**wf_kwargs_dict, ignore_empties=ignore_empties)
         except AttributeError as e:
             raise Exception(f"{e.args} in {file_path}") from e
 
